@@ -24,7 +24,7 @@ def push(project, message):
     docker = make_runner(project)
     container = docker.run_install()
     if not container.is_success():
-        print "Error while preparing image:"
+        print("Error while preparing image:")
         container.print_log()
         exit("Push command failed")
     config = {'Cmd': project.sdk_runner_command, 'Entrypoint': project.docker_entrypoint}
@@ -46,7 +46,7 @@ def push_schema(project, container):
         wrapper_data = json.load(fp)  # json.loads(self.docker.logs(c))
 
     if not wrapper_data:
-        print 'No wrappers registered (empty __init__.py?). Exiting.'
+        print('No wrappers registered (empty __init__.py?). Exiting.')
         exit(1)
 
     push_data = {'message': container.message or 'NO COMMIT MESSAGE',
@@ -57,7 +57,7 @@ def push_schema(project, container):
         url = push_url(project, container.user)
         try:
             push_json(url, push_data, container.token)
-        except requests.HTTPError, e:
+        except requests.HTTPError as e:
             if e.response.status_code in (401, 402):
                 container.load_credentials(renew=True)
                 push_json(url, push_data, container.token)
