@@ -75,10 +75,10 @@ class Container(object):
 
     def print_log(self):
         if self.is_running():
-            for out in self.docker.attach(container=self.container):
-                print out.rstrip()
+            for out in self.docker.attach(container=self.container, stream=True):
+                print(out.rstrip())
         else:
-            print self.docker.logs(self.container)
+            print(self.docker.logs(self.container))
 
     def commit(self, message=None, config=None, tag=True):
         if message:
@@ -88,7 +88,7 @@ class Container(object):
         if tag and self.project.name and self.user:
             self.docker.tag(self.image['Id'], self.repository, tag=self.tag)
         else:
-            print "Image ID:", self.tag
+            print("Image ID:", self.tag)
         return self
 
     def save_as_base(self):
