@@ -21,13 +21,13 @@ DEFAULT_CONFIG = {
     'shell_type': 'bash',
     'pip_options': '-q --download-cache /sb/pip_cache',
     'sdk_runner_command': ['/usr/bin/python', '-m', 'sbgsdk.cli'],
-    'schema_server_url': 'https://beta2-48.sbgenomics.com:1180',
-    'file_server_url': 'beta2-48.sbgenomics.com',
+    'schema_server_url': 'https://hatchery.sbgenomics.com',
+    'file_server_url': 'fs.sbgenomics.com',
     'vs_client_path': '/opt/vsclient/bin/vsclient.sh',
 
-    'docker_registry_name': 'docker.sbgenomics.com:8888',
+    'docker_registry_name': 'images.sbgenomics.com',
     'docker_registry_version': '1',
-    'docker_registry_schema': 'http',
+    'docker_registry_schema': 'https',
     'docker_daemon_url': 'unix://var/run/docker.sock',
     'docker_protocol_version': '1.8',
     'docker_user': 'sbg',
